import * as React from "react";
import styled from "styled-components/native";
import useScrollbarSize from "react-scrollbar-size";
import { AppbarAction, AppbarBackAction, AppbarContent, AppbarHeader } from "react-native-simple-elements/components/Appbar";
import useScreenSize from "react-native-simple-elements/components/Container/utils/useScreenSize";
import AuthorizedUserMenu from "../AuthorizedUserMenu";
import HomeIcon from "@mdi/svg/svg/home.svg";
import AccountIcon from "@mdi/svg/svg/account.svg";
import { View } from "react-native";
const HeaderContainer = styled.View({
  zIndex: 3
});
const DesktopLeftContentWrapper = styled.View({
  width: 240,
  flexDirection: "row",
  alignItems: "center"
});
const defaultProps = {
  isUserIconCircle: true,
  shouldCheckScrollbarSize: false
};

const SimpleHeader = props => {
  const {
    title,
    subtitle,
    mobileLeft,
    mobileContent,
    mobileRight,
    desktopLeft,
    desktopContent,
    desktopRight,
    showBackIcon,
    backButtonIcon,
    onHomeActionPress,
    onBackActionPress,
    loggedInUser,
    isUserIconCircle,
    shouldCheckScrollbarSize,
    onLoginClick,
    onViewProfileClick,
    onLogoutClick,
    userMenuItems,
    onUserMenuItemPress
  } = props;
  const {
    isMobileView
  } = useScreenSize();
  const {
    width: scrollbarSize
  } = useScrollbarSize();

  const _handleBackActionPress = () => {
    if (showBackIcon) {
      if (typeof onBackActionPress === "function") {
        onBackActionPress();
      }
    } else {
      if (typeof onHomeActionPress === "function") {
        onHomeActionPress();
      }
    }
  };

  const _handleLoginClick = () => {
    if (typeof onLoginClick === "function") {
      onLoginClick();
    }
  };

  return /*#__PURE__*/React.createElement(HeaderContainer, {
    style: {
      marginRight: shouldCheckScrollbarSize ? scrollbarSize || 0 : 0
    }
  }, /*#__PURE__*/React.createElement(AppbarHeader, null, isMobileView ? /*#__PURE__*/React.createElement(React.Fragment, null, mobileLeft ? mobileLeft() : /*#__PURE__*/React.createElement(AppbarBackAction, {
    icon: showBackIcon ? backButtonIcon : HomeIcon,
    onPress: _handleBackActionPress
  })) : null, !isMobileView && desktopLeft ? /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(DesktopLeftContentWrapper, null, desktopLeft ? desktopLeft() : null)) : null, isMobileView ? /*#__PURE__*/React.createElement(React.Fragment, null, mobileContent ? mobileContent() : /*#__PURE__*/React.createElement(AppbarContent, {
    title: title,
    subtitle: subtitle
  })) : null, !isMobileView ? /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 1,
      flexDirection: "row",
      alignItems: "center"
    }
  }, desktopContent ? desktopContent() : null) : null, isMobileView && mobileRight ? mobileRight() : null, !isMobileView && desktopRight ? desktopRight() : null, loggedInUser !== null && loggedInUser !== void 0 && loggedInUser.userId ? /*#__PURE__*/React.createElement(AuthorizedUserMenu, {
    circle: isUserIconCircle,
    loggedInUser: loggedInUser,
    onViewProfileClick: onViewProfileClick,
    onLogoutClick: onLogoutClick,
    userMenuItems: userMenuItems,
    onUserMenuItemPress: onUserMenuItemPress
  }) : /*#__PURE__*/React.createElement(AppbarAction, {
    icon: AccountIcon,
    onPress: _handleLoginClick
  })));
};

SimpleHeader.defaultProps = defaultProps;
export default SimpleHeader;
//# sourceMappingURL=SimpleHeader.js.map